[llvm-commits] CVS: llvm/include/llvm/BasicBlock.h Function.h Module.h Use.h

Chris Lattner lattner at cs.uiuc.edu
Sat Jan 29 16:08:42 PST 2005



Changes in directory llvm/include/llvm:

BasicBlock.h updated: 1.46 -> 1.47
Function.h updated: 1.58 -> 1.59
Module.h updated: 1.56 -> 1.57
Use.h updated: 1.9 -> 1.10
---
Log message:

Improve conformance with the Misha spelling benchmark suite


---
Diffs of the changes:  (+18 -18)

 BasicBlock.h |    6 +++---
 Function.h   |   12 ++++++------
 Module.h     |   12 ++++++------
 Use.h        |    6 +++---
 4 files changed, 18 insertions(+), 18 deletions(-)


Index: llvm/include/llvm/BasicBlock.h
diff -u llvm/include/llvm/BasicBlock.h:1.46 llvm/include/llvm/BasicBlock.h:1.47
--- llvm/include/llvm/BasicBlock.h:1.46	Sat Jan 29 12:41:00 2005
+++ llvm/include/llvm/BasicBlock.h	Sat Jan 29 18:08:26 2005
@@ -40,9 +40,9 @@
 
 template<> struct ilist_traits<Instruction>
   : public SymbolTableListTraits<Instruction, BasicBlock, Function> {
-  // createSentinal is used to create a node that marks the end of the list...
-  static Instruction *createSentinal();
-  static void destroySentinal(Instruction *I) { delete I; }
+  // createSentinel is used to create a node that marks the end of the list...
+  static Instruction *createSentinel();
+  static void destroySentinel(Instruction *I) { delete I; }
   static iplist<Instruction> &getList(BasicBlock *BB);
 };
 


Index: llvm/include/llvm/Function.h
diff -u llvm/include/llvm/Function.h:1.58 llvm/include/llvm/Function.h:1.59
--- llvm/include/llvm/Function.h:1.58	Sat Jan 29 12:41:00 2005
+++ llvm/include/llvm/Function.h	Sat Jan 29 18:08:26 2005
@@ -31,18 +31,18 @@
 template<> struct ilist_traits<BasicBlock>
   : public SymbolTableListTraits<BasicBlock, Function, Function> {
 
-  // createSentinal is used to create a node that marks the end of the list...
-  static BasicBlock *createSentinal();
-  static void destroySentinal(BasicBlock *BB) { delete BB; }
+  // createSentinel is used to create a node that marks the end of the list...
+  static BasicBlock *createSentinel();
+  static void destroySentinel(BasicBlock *BB) { delete BB; }
   static iplist<BasicBlock> &getList(Function *F);
 };
 
 template<> struct ilist_traits<Argument>
   : public SymbolTableListTraits<Argument, Function, Function> {
 
-  // createSentinal is used to create a node that marks the end of the list...
-  static Argument *createSentinal();
-  static void destroySentinal(Argument *A) { delete A; }
+  // createSentinel is used to create a node that marks the end of the list...
+  static Argument *createSentinel();
+  static void destroySentinel(Argument *A) { delete A; }
   static iplist<Argument> &getList(Function *F);
 };
 


Index: llvm/include/llvm/Module.h
diff -u llvm/include/llvm/Module.h:1.56 llvm/include/llvm/Module.h:1.57
--- llvm/include/llvm/Module.h:1.56	Sat Jan 29 12:41:00 2005
+++ llvm/include/llvm/Module.h	Sat Jan 29 18:08:26 2005
@@ -32,16 +32,16 @@
 
 template<> struct ilist_traits<Function>
   : public SymbolTableListTraits<Function, Module, Module> {
-  // createSentinal is used to create a node that marks the end of the list.
-  static Function *createSentinal();
-  static void destroySentinal(Function *F) { delete F; }
+  // createSentinel is used to create a node that marks the end of the list.
+  static Function *createSentinel();
+  static void destroySentinel(Function *F) { delete F; }
   static iplist<Function> &getList(Module *M);
 };
 template<> struct ilist_traits<GlobalVariable>
   : public SymbolTableListTraits<GlobalVariable, Module, Module> {
-  // createSentinal is used to create a node that marks the end of the list.
-  static GlobalVariable *createSentinal();
-  static void destroySentinal(GlobalVariable *GV) { delete GV; }
+  // createSentinel is used to create a node that marks the end of the list.
+  static GlobalVariable *createSentinel();
+  static void destroySentinel(GlobalVariable *GV) { delete GV; }
   static iplist<GlobalVariable> &getList(Module *M);
 };
 


Index: llvm/include/llvm/Use.h
diff -u llvm/include/llvm/Use.h:1.9 llvm/include/llvm/Use.h:1.10
--- llvm/include/llvm/Use.h:1.9	Sat Jan 29 12:43:28 2005
+++ llvm/include/llvm/Use.h	Sat Jan 29 18:08:26 2005
@@ -84,12 +84,12 @@
   static void setPrev(Use *N, Use *Prev) { N->UseLinks.Prev = Prev; }
   static void setNext(Use *N, Use *Next) { N->UseLinks.Next = Next; }
 
   /// createSentinal - this is used to create the end marker for the use list.
   /// Note that we only allocate a UseLinks structure, which is just enough to
   /// hold the next/prev pointers.  This saves us 8 bytes of memory for every
   /// Value allocated.
-  static Use *createSentinal() { return (Use*)new Use::NextPrevPtrs(); }
-  static void destroySentinal(Use *S) { delete (Use::NextPrevPtrs*)S; }
+  static Use *createSentinel() { return (Use*)new Use::NextPrevPtrs(); }
+  static void destroySentinel(Use *S) { delete (Use::NextPrevPtrs*)S; }
 
   void addNodeToList(Use *NTy) {}
   void removeNodeFromList(Use *NTy) {}
@@ -84,12 +84,12 @@
   static void setNext(Use *N, Use *Next) { N->UseLinks.Next = Next; }
 
-  /// createSentinal - this is used to create the end marker for the use list.
+  /// createSentinel - this is used to create the end marker for the use list.
   /// Note that we only allocate a UseLinks structure, which is just enough to
   /// hold the next/prev pointers.  This saves us 8 bytes of memory for every






More information about the llvm-commits mailing list